@@ -267,6 +267,8 @@ class openvpn_applet(hildondesktop.StatusMenuItem):
         #self.button = gtk.Button("OpenVPN");
         self.button.connect("clicked", self.button_clicked_event)
         
+        self.status_area_icon = gtk.gdk.pixbuf_new_from_file_at_size("/usr/share/icons/hicolor/48x48/apps/openvpn-applet.png", 18, 18)
+
         self.add(self.button)
         self.show_all()
         self.update_list()
@@ -291,23 +293,30 @@ class openvpn_applet(hildondesktop.StatusMenuItem):
     
     def update_button(self):
         log("update_button")
-        self.timeout = self.timeout - 1
         active = self.vc.get_active_connections_number()
         if active == 1:
             self.button.set_text(self.button_title_text, str(active) + ' active connection')
+            self.set_status_area_icon(self.status_area_icon)
         elif active > 1:
             self.button.set_text(self.button_title_text, str(active) + ' active connections')
+            self.set_status_area_icon(self.status_area_icon)
         else:
             self.button.set_text(self.button_title_text, 'no active connections')
-            
+            self.set_status_area_icon(None)
+
+    def update_button_timer(self):
+        self.timeout = self.timeout - 1
+        self.update_button()
         if self.timeout > 0:
-            self.timer = gobject.timeout_add(500, self.update_button)
+            self.timer = gobject.timeout_add(500, self.update_button_timer)
+        elif self.vc.get_active_connections_number() > 0:
+            self.timer = gobject.timeout_add(30000, self.update_button_timer)
         else:
             self.timer = None
             return False
 
     def settings_event(self, widget, data=None):
-        widget = gtk.MenuItem("Openvpn setup")
+        widget = gtk.MenuItem("OpenVPN setup")
         widget.connect("activate", self.open_settings)
         return widget
         
@@ -342,7 +351,7 @@ class openvpn_applet(hildondesktop.StatusMenuItem):
                 self.banner = hildon.hildon_banner_show_information(self,"", "Stopping Openvpn Connection")
                 self.vc.stop(vpn_number)
             self.timeout = 10
-            self.timer = gobject.timeout_add(500, self.update_button)
+            self.timer = gobject.timeout_add(500, self.update_button_timer)
         elif vpn_number == self.vc.get_vpn_count():
             print "open settings"
             self.open_settings(self)
@@ -350,13 +359,13 @@ class openvpn_applet(hildondesktop.StatusMenuItem):
 def user_pass_dlg(ask_passwd):
     if ask_passwd:
         dlg = hildon.LoginDialog(gtk.Window())
-        dlg.set_message("Openvpn Authentication")
+        dlg.set_message("OpenVPN Authentication")
         response = dlg.run()
         user_pass_resp = (dlg.get_username(),dlg.get_password())
         dlg.destroy()
     else:
         dlg = hildon.GetPasswordDialog(gtk.Window(),False)
-        dlg.set_message("Openvpn Authentication")
+        dlg.set_message("OpenVPN Authentication")
         response = dlg.run()
         user_pass_resp = (None,dlg.get_password())
         dlg.destroy()
@@ -393,7 +402,7 @@ class SelectConnectionDialog(gtk.Dialog):
         self.vbox.pack_start(pannable_area)
         self.action_area.show_all()
         self.vbox.show_all()
-        self.set_size_request(800,(vpn_manager.get_vpn_count()+1)*50+35)
+        self.set_size_request(800,(vpn_manager.get_vpn_count()+1)*50+50)
         #self.show_all()
 
 
@@ -402,7 +411,7 @@ class SelectConnectionDialog(gtk.Dialog):
         self.destroy()
 
 class OpenvpnAppletSettings(gtk.Dialog):
-    def __init__(self,title="Openvpn connections", parent=None, flags=0, buttons=None, vpn_manager=None, applet=None):
+    def __init__(self,title="OpenVPN connections", parent=None, flags=0, buttons=None, vpn_manager=None, applet=None):
         gtk.Dialog.__init__(self,title, parent, flags, buttons)
 
         self.vpn_manager = vpn_manager
@@ -672,7 +681,7 @@ class FileLinks(UserDict):
             self.type = 'file'
         
         self.update()
-        
+        self.filter(['/etc/openvpn/maemo-update-resolvconf'], 'blacklist')
         
     def update(self):
         log("function: update")
@@ -744,16 +753,25 @@ class FileLinks(UserDict):
             self.files_not_found = []
         return self.files_not_found
         
-    def filter(self,whitelist):
+    def filter(self,wordlist,mode='whitelist'):
+        log("function: filter", wordlist, mode)
         for key in self.data:
             passed_files = []
             for file in self.data[key]:
                 if os.path.isabs(file):
-                    for wl in whitelist:
-                        if re.search('^'+wl,file):
-                            passed_files.append(file)
-                        else:
-                            log("Dropped:", file)
+                    for wl in wordlist:
+                        if mode == 'whitelist':
+                            if re.search('^'+wl,file):
+                                log("Passed:", file)
+                                passed_files.append(file)
+                            else:
+                                log("Dropped:", file)
+                        else: #'blacklist'
+                            if not re.search('^'+wl,file):
+                                passed_files.append(file)
+                                log("Passed:", file)
+                            else:
+                                log("Dropped:", file)
             self.data[key] = passed_files
                         
     
